#
# spec file for package gzdoom
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gzdoom
Version:        3.2.5
Release:        bp153.1.19
Summary:        A DOOM source port with graphic and modding extensions
License:        GPL-3.0
Group:          Amusements/Games/3D/Shoot
Url:            http://zdoom.org/

#Git-Clone:     https://github.com/coelckers/gzdoom
Source:         %name-%version.tar.xz
Patch1:         gzdoom-waddir.patch
Patch2:         gzdoom-wadsrc-extra.patch
Patch3:         gzdoom-staticlibs.patch
Patch4:         0001-Update-LZMA-SDK-to-version-17.01.patch
Patch5:         gzdoom-lzma.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cmake >= 2.8.7
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  nasm
BuildRequires:  pkg-config
BuildRequires:  unzip
BuildRequires:  xz
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libgme)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig(clzma) >= 17.01
%else
Provides:       bundled(lzma-sdk) = 17.01
%endif
%if 0%{?suse_version} == 1315
BuildRequires:  gcc6-c++
%endif
Recommends:     freedoom
Recommends:     timidity
Recommends:     timidity-eawpats
Provides:       qzdoom = 1.3.0
Provides:       zdoom = 2.8.1
# DUMB is modified to read OggVorbis samples
Provides:       bundled(dumb) = 0.9.3
Provides:       bundled(gdtoa)
Provides:       bundled(re2c) = 0.16.0

%description
GZDoom is a port (a modification) of the original Doom source code, featuring:
* an OpenGL renderer, HQnX rescaling, 3D floor and model support
* Truecolor software rendering, extending the classic 8-bit palette
* a three-point projection software renderer, extending the classic
  2-point projection
* Heretic, Hexen and Strife game modes and support for a lot of
  additional IWADs.
* Boom and Hexen map extension support, scriptability with ACS and
  ZScript, and various modding features regarding actors and scenery.
* Demo record/playback of classic and Boom demos is not supported.

%prep
%setup -q
%patch -P 1 -P 2 -P 3 -P 4 -p1
%if 0%{?suse_version} >= 1500
%patch -P 5 -p1
%endif
perl -i -pe 's{__DATE__}{""}g' src/posix/sdl/i_main.cpp
perl -i -pe 's{<unknown version>}{%version}g' \
	tools/updaterevision/updaterevision.c

%build
# We must not strip - %%debug_package will take care of it
# Deactivate -Wl,--as-needed
%cmake -DNO_STRIP=1 \
%if 0%{suse_version} == 1315
	-DCMAKE_C_COMPILER=gcc-6 -DCMAKE_CXX_COMPILER=g++-6 \
%endif
	-DCMAKE_SHARED_LINKER_FLAGS="" \
	-DCMAKE_EXE_LINKER_FLAGS="" -DCMAKE_MODULE_LINKER_FLAGS="" \
	-DINSTALL_DOCS_PATH="%_defaultdocdir/%name" \
	-DINSTALL_PK3_PATH="%_datadir/doom"
make %{?_smp_mflags}

%install
%cmake_install

%post
echo "INFO: %name: The global IWAD directory is %_datadir/doom."

%files
%_bindir/%name
%_defaultdocdir/%name
%_datadir/doom/

%changelog
* Mon Jan  8 2018 jengelh@inai.de
- Update to new upstream 3.2.5
  * Implemented 'i_soundinbackground' to continue playing sounds
    and music while in background.
  * OpenGL rendering now continues even when losing focus if not
    running fullscreen.
  * Added 'playerrespawn' skill flag to allow gameplay mods to
    retroactively enable player respawns in single player on
    all maps.
  * Improved Advanced Sound Options menu - added option for
    FluidSynth chorus, removed fractional part from FluidSynth
    voices option.
  * Fixed applying of Doom 64 lighting to horizon portals.
  * Particles are now interpolated.
- Use system lzma-sdk
- Add 0001-Update-LZMA-SDK-to-version-17.01.patch,
  gzdoom-lzma.patch, gzdoom-wadsrc-extra.patch
* Tue Jan  2 2018 jengelh@inai.de
- Remove zdoom from the specfile (which had built both zdoom and
  gzdoom due to their similarity) and rename to gzdoom.spec.
- Update to new upstream release 3.2.4
  * Recognition for the HacX 2.0 IWAD
  * Recognition for the modified Doom 1/2/U IWADs and the "No Rest
    for the Living" expansion pack shipped in the Doom3 BFG Edition.
  * New GL3 node format for complex UDMF maps which need fractional
    precision on node splitters.
  * The ZScript scripting language has been added.
  * A new 32-bit software renderer has been added.
    The classic 8-bit renderer remains available.
- Add gzdoom-waddir.patch, gzdoom-staticlibs.patch.
* Sun Mar 24 2013 jengelh@inai.de
- Standardize on /usr/share/doom for IWADs.
- Per-user configuration is to be moved to ~/.config/zdoom
  (XDG environment variables are not respected, though),
  ~/.config/gzdoom and ~/.config/zandronum for the different
  game engines respectively.
* Thu Mar 21 2013 jengelh@medozas.de
- Update to new upstream release zdoom-2.6.0+svn4191
  and gzdoom-1.7.01+svn1526
  * berserk indicator on alternative HUD
  * support for BFG edition IWADs
  * sound precaching through MAPINFO.
- Imported zandronum-1.0+hg3641 (formerly Skulltag)
* Tue Jul 10 2012 jengelh@inai.de
- Update to new upstream release 2.6.0 (gzdoom-1.6.0)
  * Added Hacx IWAD support.
  * Added text-format Strife conversation system with USDF and ZSDF.
  * A textured automap is now available; automap graphics are now
  externalized.
  * Rewritten menu system, which can now be defined with the MENUDEF
  lump.
  * Externalized intermissions to MAPINFO.
  * Externalized IWAD detection and gave each IWAD its own
  independent config section.
  * Added FluidSynth and GUS emulator softsynths; fixed issues with
  TiMidity++.
  * Added VOC support and enhanced MIDI playback with support for
  alternative formats such as XMI and HMI.
  * Action specials: Added Ceiling_LowerAndCrushDist and
  Thing_SetConversation. Added console command to execute specials.
  * ACS: Increased maximum script number from 999 to 32767.
  * ACS: Named scripts allow to avoid script number conflicts
  altogether.
  * ACS: Added StrCopy, CheckSight, SetActivator, SetPointer
  functions.
  * ACS: Added APROP_ScaleX/Y and APROP_Mass actor properties.
  * ACS: Added temporary dynamic strings variables with StrParam.
  * ACS: Scripts can now have up to four parameters.
  * DECORATE: Added A_CheckFlag, A_FaceMaster, A_FaceTracer,
  A_RadiusGive, A_SetMass, A_SetScale, A_Warp and A_WolfAttack...
  * DECORATE: Enhanced A_AlertMonsters, A_BFGSpray, A_Blast,
  A_CustomBulletAttack, A_FireBullets, A_GunFlash, A_PainAttack,
  A_RadiusThrust...
  * DECORATE: Added an actor pointer manipulation system with several
  new codepointers...
  * DECORATE: Added DOHARMSPECIES, DONTCORPSE, SEEINVISIBLE and
  INVENTORY.UNTOSSABLE
  * DECORATE: Increased damage type flexibility in several ways with
  DeathType and PainType.
  * DECORATE: Added customizable fléchettes.
  * DECORATE: Made accuracy and stamina accessible through DECORATE
  expressions.
  * DECORATE: Added ProjectileKickback, Inventory.RestrictedTo and
  Inventory.ForbiddenTo class-based properties.
  * DECORATE: Backported VisibleToTeam, VisibleToPlayerClass and
  weapon DropItem feature from Skulltag, and enhanced them.
  * DECORATE: Added "Fast" keyword for states and deprecated the
  unreliable FASTER and FASTMELEE flags.
  * Added a secret hint system.
  * 3D floors support.
  * FraggleScript support.
  * Voxel support.
  * SBARINFO: Ammo 1/2 capacities added to DrawNumber, support for
  color names in colored text.
  * SNDINFO: Added musicalias and attenuation.
  * Compatibility: fixed issues with Eternal Doom, Happy Time Circus,
  Phobos, vanilla compat, Boom compat, light levels higher than
  255, Heretic, Strife, MUSINFO, misnamed UDMF field.
  * Fixed loading of BMF palettes.
  * restart console command.
  * Added PALVERS lump for specifying alternate graphics to use with
  a paletted render, in case the graphics you really want to use
  look bad without true color.
  * Custom IWADs no longer need to include a COLORMAP, as ZDoom will
  generate one automatically if it is missing.
  * Fixed vertical tiling of non-power-of-two textures.
* Sat Nov 27 2010 jengelh@medozas.de
- cmake is really weird when it comes to CFLAGS.
  Pass :STRING= to make it actually use our flags.
- set RPM group for gzdoom to one that rpmlint accepts
- disable strip to make debuginfo packages work
- fix a crash caused by an uninitialized variable
* Fri Sep 10 2010 jengelh@medozas.de
- Enable building with experimental fluidsynth support
- Optimize PNGs before packing up
- Do not use FMODEx for building on non-x86
- Remove unneeded p7zip build dependency (repacked + patched
  .tar.xz is used since a while)
- Update to ZDoom 2.5.0
  * Obsoleted zdoom-binutils.diff
- Update to GZDoom 1.5.02
* Fri Jul 30 2010 jengelh@medozas.de
- Add patch to workaround compile issues with binutils 2.20.0
* Wed Jul 28 2010 jengelh@medozas.de
- Split up zdoom package into its components
- zdoom, gzdoom, zdoom-devel
